from distutils.core import setup

setup(
		name 			= 'egnester',
		version			= '1.0.0',
		py_modules		= ['egnester'],
		author			= 'ekramGaleti',
		author_email	= 'enigmaekkui@gmail.com',
		url				= 'www.perfectgirls.net',
		description		= 'Lists in Lists in Listes.......and so on',
)